"use server";

import { authClient } from "@/lib/auth-client";
import prisma from "@/lib/db";
import { signUpFormSchema } from "@/lib/schemas";
// import type { User } from "@prisma/client";
import { redirect } from "next/navigation";
import { z } from "zod";
import { headers } from "next/headers";
const formSchema = z.object({
	phoneNumber: z
		.string()
		.regex(/^[7|9][0-9]{2}-[0-9]{4}$/, "Please enter a valid phone number"),
});

export async function signin(
	previousState: ActionState,
	formData: FormData,
) {
	const phoneNumber = formData.get("phoneNumber") as string;
	const result = formSchema.safeParse({ phoneNumber });
	console.log(phoneNumber);

	if (!result.success) {
		return {
			message: result.error.errors[0].message, // Get the error message from Zod
			status: "error",
		};
	}

	if (!phoneNumber) {
		return {
			message: "Please enter a phone number",
			status: "error",
		};
	}
	const NUMBER_WITH_COUNTRY_CODE: string = `+960${phoneNumber.split("-").join("")}`;

	const userExists = await prisma.user.findUnique({
		where: {
			phoneNumber: NUMBER_WITH_COUNTRY_CODE,
		},
	});
	if (!userExists) {
		return redirect(`/signup?phone_number=${phoneNumber}`);
	}
	await authClient.phoneNumber.sendOtp({
		phoneNumber: NUMBER_WITH_COUNTRY_CODE,
	});
	redirect(`/verify-otp?phone_number=${encodeURIComponent(phoneNumber)}`);
}

type ActionState = {
	message: string;
	payload?: FormData;
};

export async function signup(
	_actionState: ActionState,
	formData: FormData,
) {
	const data = Object.fromEntries(formData.entries());
	const parsedData = signUpFormSchema.safeParse(data);
	// get phone number from /signup?phone_number=999-1231
	const headersList = await headers()
	const referer = headersList.get("referer")
	const number = referer?.split("?")[1]?.split("=")[1]
	let NUMBER_WITH_COUNTRY_CODE: string

	console.log(data)

	if (!parsedData.success) {
		return {
			message: "Invalid form data",
			payload: formData,
			errors: parsedData.error.flatten(),
		};
	}
	if (parsedData.data.name.includes("a")){
		return {
			message: "ID card already exists.",
			payload: formData,
			db_error: "id_card",
		};
	}

	if (number) {
		NUMBER_WITH_COUNTRY_CODE = `+960${number.split("-").join("")}`
	} else {
		NUMBER_WITH_COUNTRY_CODE = `+960${parsedData.data.phone_number.split("-").join("")}`;
	}
	console.log({NUMBER_WITH_COUNTRY_CODE})
	const idCardExists = await prisma.user.findFirst({
		where: {
			id_card: parsedData.data.id_card,
		},
	});
	if (idCardExists) {
		return {
			message: "ID card already exists.",
			payload: formData,
			db_error: "id_card",
		};
	}
	//  const newUser = await prisma.user.create({
	// 	data: {
	// 		name: parsedData.data.name,
	// 		islandId: "1",
	// 		atollId: "1",
	// 		house_name: parsedData.data.house_name,
	// 		id_card: parsedData.data.id_card,
	// 		dob: parsedData.data.dob,
	// 		phoneNumber: NUMBER_WITH_COUNTRY_CODE,
	// 	},
	// });
	// await authClient.phoneNumber.sendOtp({
	// 	phoneNumber: newUser.phoneNumber,
	// });
	// redirect(`/verify-otp?phone_number=${encodeURIComponent(newUser.phoneNumber)}`);

	return { message: "Post created" };
}

export const sendOtp = async (phoneNumber: string, code: string) => {
	// Implement sending OTP code via SMS
	console.log("Send OTP server fn", phoneNumber, code);
	const respose = await fetch("https://smsapi.sarlink.link/send", {
		method: "POST",
		headers: {
			"Content-Type": "application/json",
		},
		body: JSON.stringify({
			api_key: process.env.SMS_API_KEY,
			number: phoneNumber,
			text: `Your OTP code is ${code}`,
		}),
	});
	const data = await respose.json();
	console.log(data);
	return data;
};
