import type { Metadata } from "next";
import "./globals.css";
import { ThemeProvider } from "@/components/theme-provider";
import { Barlow } from "next/font/google";
import NextTopLoader from 'nextjs-toploader';
import { Toaster } from 'sonner'

const barlow = Barlow({
	subsets: ["latin"],
	weight: ["100", "300", "400", "500", "600", "700", "800", "900"],
	variable: "--font-barlow",
});

export const metadata: Metadata = {
	title: "Create Next App",
	description: "Generated by create next app",
};

export default function RootLayout({
	children,
}: Readonly<{
	children: React.ReactNode;
}>) {
	return (
		<html lang="en" suppressHydrationWarning>
			<body className={`${barlow.variable} antialiased font-sans`}>
				<NextTopLoader showSpinner={false} zIndex={9999} />
				<Toaster richColors />
				<ThemeProvider
					attribute="class"
					defaultTheme="system"
					enableSystem
					disableTransitionOnChange
				>
					{children}
				</ThemeProvider>
			</body>
		</html>
	);
}
